==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceProviderManifestPropertiesManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property incidentContactEmail
 * @property incidentRoutingService
 * @property incidentRoutingTeam
 * @property manifestOwners
 * @property resourceAccessPolicy
 * @property resourceAccessRoles
 * @property schemaOwners
 * @property serviceTreeInfos
 */
public data class ResourceProviderManifestPropertiesManagementArgs(
    public val incidentContactEmail: Output<String>? = null,
    public val incidentRoutingService: Output<String>? = null,
    public val incidentRoutingTeam: Output<String>? = null,
    public val manifestOwners: Output<List<String>>? = null,
    public val resourceAccessPolicy: Output<String>? = null,
    public val resourceAccessRoles: Output<List<Any>>? = null,
    public val schemaOwners: Output<List<String>>? = null,
    public val serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs.builder()
            .incidentContactEmail(incidentContactEmail?.applyValue({ args0 -> args0 }))
            .incidentRoutingService(incidentRoutingService?.applyValue({ args0 -> args0 }))
            .incidentRoutingTeam(incidentRoutingTeam?.applyValue({ args0 -> args0 }))
            .manifestOwners(manifestOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceAccessPolicy(resourceAccessPolicy?.applyValue({ args0 -> args0 }))
            .resourceAccessRoles(resourceAccessRoles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .schemaOwners(schemaOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .serviceTreeInfos(
                serviceTreeInfos?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceProviderManifestPropertiesManagementArgs].
 */
@PulumiTagMarker
public class ResourceProviderManifestPropertiesManagementArgsBuilder internal constructor() {
    private var incidentContactEmail: Output<String>? = null

    private var incidentRoutingService: Output<String>? = null

    private var incidentRoutingTeam: Output<String>? = null

    private var manifestOwners: Output<List<String>>? = null

    private var resourceAccessPolicy: Output<String>? = null

    private var resourceAccessRoles: Output<List<Any>>? = null

    private var schemaOwners: Output<List<String>>? = null

    private var serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null

    /**
     * @param value
     */
    @JvmName("kpujsqerovgpmkhx")
    public suspend fun incidentContactEmail(`value`: Output<String>) {
        this.incidentContactEmail = value
    }

    /**
     * @param value
     */
    @JvmName("mlaejexipetxictl")
    public suspend fun incidentRoutingService(`value`: Output<String>) {
        this.incidentRoutingService = value
    }

    /**
     * @param value
     */
    @JvmName("ermbnirosjajsmop")
    public suspend fun incidentRoutingTeam(`value`: Output<String>) {
        this.incidentRoutingTeam = value
    }

    /**
     * @param value
     */
    @JvmName("atdommqivihndtij")
    public suspend fun manifestOwners(`value`: Output<List<String>>) {
        this.manifestOwners = value
    }

    @JvmName("sjjcvvnhvqvfqfaf")
    public suspend fun manifestOwners(vararg values: Output<String>) {
        this.manifestOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("kkgpwyubnjlffcup")
    public suspend fun manifestOwners(values: List<Output<String>>) {
        this.manifestOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("fafdwdqeifitcawo")
    public suspend fun resourceAccessPolicy(`value`: Output<String>) {
        this.resourceAccessPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("kycskfkobwkbhkad")
    public suspend fun resourceAccessRoles(`value`: Output<List<Any>>) {
        this.resourceAccessRoles = value
    }

    @JvmName("yfbtqfeqbfxplrlj")
    public suspend fun resourceAccessRoles(vararg values: Output<Any>) {
        this.resourceAccessRoles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rdbqlfaxpdwsjeha")
    public suspend fun resourceAccessRoles(values: List<Output<Any>>) {
        this.resourceAccessRoles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("sussgxwxtyvllrcf")
    public suspend fun schemaOwners(`value`: Output<List<String>>) {
        this.schemaOwners = value
    }

    @JvmName("ltnmhwvdsyslojmw")
    public suspend fun schemaOwners(vararg values: Output<String>) {
        this.schemaOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("nvlehnlifutqrwmc")
    public suspend fun schemaOwners(values: List<Output<String>>) {
        this.schemaOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pdamcmdiktdsrjnk")
    public suspend fun serviceTreeInfos(`value`: Output<List<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = value
    }

    @JvmName("njyqcatoshxcigpa")
    public suspend fun serviceTreeInfos(vararg values: Output<ServiceTreeInfoArgs>) {
        this.serviceTreeInfos = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jeeplyjkpqrlurfy")
    public suspend fun serviceTreeInfos(values: List<Output<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("oblafdhlhymcaiuf")
    public suspend fun incidentContactEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentContactEmail = mapped
    }

    /**
     * @param value
     */
    @JvmName("ijoevseskknitpll")
    public suspend fun incidentRoutingService(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingService = mapped
    }

    /**
     * @param value
     */
    @JvmName("rfkshgetwlnrgmiy")
    public suspend fun incidentRoutingTeam(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingTeam = mapped
    }

    /**
     * @param value
     */
    @JvmName("mcvjggdswlccbyrm")
    public suspend fun manifestOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("iliakxgixacinjva")
    public suspend fun manifestOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("gvmxtsepuargsgpx")
    public suspend fun resourceAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("sqhgsggwvibaqfxn")
    public suspend fun resourceAccessRoles(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param values
     */
    @JvmName("fapkifwvicbpqvvm")
    public suspend fun resourceAccessRoles(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param value
     */
    @JvmName("byhppkveyrogmxdb")
    public suspend fun schemaOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("ifnlgldqqoefkawj")
    public suspend fun schemaOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("npslbhcbmektxubv")
    public suspend fun serviceTreeInfos(`value`: List<ServiceTreeInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ptmngevwcfkxvfti")
    public suspend
    fun serviceTreeInfos(argument: List<suspend ServiceTreeInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("hqgyqljxwvpychfx")
    public suspend fun serviceTreeInfos(
        vararg
        argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("npwuplftuxpkalft")
    public suspend fun serviceTreeInfos(argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ServiceTreeInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param values
     */
    @JvmName("crqdkcvgwgdrlhgj")
    public suspend fun serviceTreeInfos(vararg values: ServiceTreeInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    internal fun build(): ResourceProviderManifestPropertiesManagementArgs =
        ResourceProviderManifestPropertiesManagementArgs(
            incidentContactEmail = incidentContactEmail,
            incidentRoutingService = incidentRoutingService,
            incidentRoutingTeam = incidentRoutingTeam,
            manifestOwners = manifestOwners,
            resourceAccessPolicy = resourceAccessPolicy,
            resourceAccessRoles = resourceAccessRoles,
            schemaOwners = schemaOwners,
            serviceTreeInfos = serviceTreeInfos,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceProviderManifestPropertiesManagementArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property incidentContactEmail
 * @property incidentRoutingService
 * @property incidentRoutingTeam
 * @property manifestOwners
 * @property resourceAccessPolicy
 * @property resourceAccessRoles
 * @property schemaOwners
 * @property serviceTreeInfos
 */
public data class ResourceProviderManifestPropertiesManagementArgs(
    public val incidentContactEmail: Output<String>? = null,
    public val incidentRoutingService: Output<String>? = null,
    public val incidentRoutingTeam: Output<String>? = null,
    public val manifestOwners: Output<List<String>>? = null,
    public val resourceAccessPolicy: Output<String>? = null,
    public val resourceAccessRoles: Output<List<Any>>? = null,
    public val schemaOwners: Output<List<String>>? = null,
    public val serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceProviderManifestPropertiesManagementArgs.builder()
            .incidentContactEmail(incidentContactEmail?.applyValue({ args0 -> args0 }))
            .incidentRoutingService(incidentRoutingService?.applyValue({ args0 -> args0 }))
            .incidentRoutingTeam(incidentRoutingTeam?.applyValue({ args0 -> args0 }))
            .manifestOwners(manifestOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .resourceAccessPolicy(resourceAccessPolicy?.applyValue({ args0 -> args0 }))
            .resourceAccessRoles(resourceAccessRoles?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .schemaOwners(schemaOwners?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .serviceTreeInfos(
                serviceTreeInfos?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceProviderManifestPropertiesManagementArgs].
 */
@PulumiTagMarker
public class ResourceProviderManifestPropertiesManagementArgsBuilder internal constructor() {
    private var incidentContactEmail: Output<String>? = null

    private var incidentRoutingService: Output<String>? = null

    private var incidentRoutingTeam: Output<String>? = null

    private var manifestOwners: Output<List<String>>? = null

    private var resourceAccessPolicy: Output<String>? = null

    private var resourceAccessRoles: Output<List<Any>>? = null

    private var schemaOwners: Output<List<String>>? = null

    private var serviceTreeInfos: Output<List<ServiceTreeInfoArgs>>? = null

    /**
     * @param value
     */
    @JvmName("pbisdtjvjepxxamv")
    public suspend fun incidentContactEmail(`value`: Output<String>) {
        this.incidentContactEmail = value
    }

    /**
     * @param value
     */
    @JvmName("rgxntouihbjropof")
    public suspend fun incidentRoutingService(`value`: Output<String>) {
        this.incidentRoutingService = value
    }

    /**
     * @param value
     */
    @JvmName("xkfvixvbtkdbsyis")
    public suspend fun incidentRoutingTeam(`value`: Output<String>) {
        this.incidentRoutingTeam = value
    }

    /**
     * @param value
     */
    @JvmName("mpdbnapmyypgjphq")
    public suspend fun manifestOwners(`value`: Output<List<String>>) {
        this.manifestOwners = value
    }

    @JvmName("oywgdgnoxnyywels")
    public suspend fun manifestOwners(vararg values: Output<String>) {
        this.manifestOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("hvsfwvmojdnjtakr")
    public suspend fun manifestOwners(values: List<Output<String>>) {
        this.manifestOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("gdlgwjebqrexcsjh")
    public suspend fun resourceAccessPolicy(`value`: Output<String>) {
        this.resourceAccessPolicy = value
    }

    /**
     * @param value
     */
    @JvmName("djmpsoikxxdfykru")
    public suspend fun resourceAccessRoles(`value`: Output<List<Any>>) {
        this.resourceAccessRoles = value
    }

    @JvmName("qmwdhmxmflftxjxo")
    public suspend fun resourceAccessRoles(vararg values: Output<Any>) {
        this.resourceAccessRoles = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("lvqpqgaqpluspmiq")
    public suspend fun resourceAccessRoles(values: List<Output<Any>>) {
        this.resourceAccessRoles = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("upyvosxoruuqxxrj")
    public suspend fun schemaOwners(`value`: Output<List<String>>) {
        this.schemaOwners = value
    }

    @JvmName("subxqylvhkeiqvgs")
    public suspend fun schemaOwners(vararg values: Output<String>) {
        this.schemaOwners = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("rtdxtcasutpjtswj")
    public suspend fun schemaOwners(values: List<Output<String>>) {
        this.schemaOwners = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xpsoknesvfumflxe")
    public suspend fun serviceTreeInfos(`value`: Output<List<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = value
    }

    @JvmName("loibusbkupcdyroe")
    public suspend fun serviceTreeInfos(vararg values: Output<ServiceTreeInfoArgs>) {
        this.serviceTreeInfos = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("jhoqhtfjukjevynv")
    public suspend fun serviceTreeInfos(values: List<Output<ServiceTreeInfoArgs>>) {
        this.serviceTreeInfos = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("spjsihacujsunrko")
    public suspend fun incidentContactEmail(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentContactEmail = mapped
    }

    /**
     * @param value
     */
    @JvmName("yruuchlmdatgfexi")
    public suspend fun incidentRoutingService(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingService = mapped
    }

    /**
     * @param value
     */
    @JvmName("sccowlbiwdjoncew")
    public suspend fun incidentRoutingTeam(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.incidentRoutingTeam = mapped
    }

    /**
     * @param value
     */
    @JvmName("tpmccxbdjjjsaitq")
    public suspend fun manifestOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("vchnhijyrbwjltjn")
    public suspend fun manifestOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.manifestOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("pbcedagmaldfqsfa")
    public suspend fun resourceAccessPolicy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessPolicy = mapped
    }

    /**
     * @param value
     */
    @JvmName("tkkxqwnkgmuvitjr")
    public suspend fun resourceAccessRoles(`value`: List<Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param values
     */
    @JvmName("orytlrdgpnjmxovj")
    public suspend fun resourceAccessRoles(vararg values: Any) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceAccessRoles = mapped
    }

    /**
     * @param value
     */
    @JvmName("ctautmqrnqivccwm")
    public suspend fun schemaOwners(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param values
     */
    @JvmName("gqtjmbnhdqsabltg")
    public suspend fun schemaOwners(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.schemaOwners = mapped
    }

    /**
     * @param value
     */
    @JvmName("udjrtfjxudubqcxm")
    public suspend fun serviceTreeInfos(`value`: List<ServiceTreeInfoArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("fjvhcgwdoistsiqw")
    public suspend
    fun serviceTreeInfos(argument: List<suspend ServiceTreeInfoArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("gbsdiukglgqamgbg")
    public suspend fun serviceTreeInfos(
        vararg
        argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            ServiceTreeInfoArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qkcfgpwyklwdygti")
    public suspend fun serviceTreeInfos(argument: suspend ServiceTreeInfoArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ServiceTreeInfoArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.serviceTreeInfos = mapped
    }

    /**
     * @param values
     */
    @JvmName("ptmnppvtocifsfdr")
    public suspend fun serviceTreeInfos(vararg values: ServiceTreeInfoArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.serviceTreeInfos = mapped
    }

    internal fun build(): ResourceProviderManifestPropertiesManagementArgs =
        ResourceProviderManifestPropertiesManagementArgs(
            incidentContactEmail = incidentContactEmail,
            incidentRoutingService = incidentRoutingService,
            incidentRoutingTeam = incidentRoutingTeam,
            manifestOwners = manifestOwners,
            resourceAccessPolicy = resourceAccessPolicy,
            resourceAccessRoles = resourceAccessRoles,
            schemaOwners = schemaOwners,
            serviceTreeInfos = serviceTreeInfos,
        )
}
